0.2.0
=====

This is a feature release which introduces new functionality to help facilitate LIGO parameter estimation analyses conducted on the LIGO Data Grid.

Breaking changes
----------------

This release is not believed to introduce any backwards-incompatible changes.

Merges
------
+ `ligo!3 <https://git.ligo.org/asimov/pipelines/gwdata/-/merge_requests/3>`_: Introduces the ability to find calibration files on the Caltech cluster.


